@@ -19,10 +19,11 @@ import base64
 import os
 import ssl
 import sys
-import warnings
+import traceback
 import uuid
 import logging
 
+
 class TalosHttpClientTransportFactory:
 
     _url = str
@@ -103,10 +104,8 @@ class TalosHttpClient(TTransportBase):
         NOTE: if both cafile and ssl_context are defined, ssl_context will override cafile.
         """
         if port is not None:
-            warnings.warn(
-                "Please use the THttpClient('http{s}://host:port/path') constructor",
-                DeprecationWarning,
-                stacklevel=2)
+            self.logger.warning("Please use the THttpClient('http{s}://host:port/path') "
+                                + "constructor", DeprecationWarning, stacklevel=2)
             self.host = uri_or_host
             self.port = port
             assert path
@@ -234,7 +233,7 @@ class TalosHttpClient(TTransportBase):
                         self.__http.putheader(constants.HK_AUTHORIZATION, authString)
                         self._headers[str(constants.HK_AUTHORIZATION).lower()] = authString
                     except Exception as e:
-                        self.logger.error("fail to sign" + e.message)
+                        self.logger.error("fail to sign" + str(traceback.format_exc()))
             else:
                 if self.credential.type == constants.UserType.APP_XIAOMI_SSO:
                     authString = "SSO " + self._sid + ":" + self.credential.secretKey + ":" + self.credential.secretKeyId
