@@ -14,6 +14,7 @@ from talos.producer.PartitionMessageQueue import PartitionMessageQueue
 from concurrent.futures import ThreadPoolExecutor
 import logging
 import threading
+import traceback
 
 
 class TASK_STATE:
@@ -85,8 +86,6 @@ class MessageCallbackTask(threading.Thread):
 class PartitionSender:
     logger = logging.getLogger("PartitionSender")
 
-    lock = threading.Lock()
-
     def __init__(self, partitionId=None, topicName=None, topicTalosResourceName=None,
                  requestId=None, clientId=None, talosProducerConfig=None,
                  messageClient=None, userMessageCallback=None, messageCallbackExecutors=None,
@@ -113,50 +112,9 @@ class PartitionSender:
         self.singleExecutor = ThreadPoolExecutor(max_workers=1, thread_name_prefix="talos-producer-" +
                                                                                    self.topicAndPartition.topicName
                                                                                    + " " + str(self.topicAndPartition.partitionId))
-#        self.messageWriterFuture = self.singleExecutor.submit(MessageWriter(self, self.globalLock))
         self.executor = MessageWriter(self, self.globalLock)
         self.executor.start()
 
-    # def message_callback_task(self, userMessageResult=None):
-    #     if userMessageResult.is_successful():
-    #         self.userMessageCallback.on_success(userMessageResult)
-    #     else:
-    #         self.userMessageCallback.on_error(userMessageResult)
-
-    # def message_writer(self):
-    #     simpleProducer = SimpleProducer(producerConfig=self.talosProducerConfig,
-    #                                     topicAndPartition=self.topicAndPartition,
-    #                                     messageClient=self.messageClient,
-    #                                     clientId=self.clientId, requestId=self.requestId)
-    #
-    #     while self.get_cur_state() == TASK_STATE.ACTIVE:
-    #         try:
-    #             messageList = self.partitionMessageQueue.get_message_list()
-    #
-    #             # when messageList return no message, this means TalosProducer not
-    #             # alive and there is no more message to send, then we should exit
-    #             # write message right now;
-    #             if len(messageList) == 0:
-    #                 # notify to wake up producer's global lock
-    #                 with self.lock:
-    #                     self.globalLock.acquire()
-    #                     self.globalLock.notifyAll()
-    #                     self.globalLock.release()
-    #                 break
-    #
-    #             self.put_message(messageList, simpleProducer)
-    #         except Exception as e:
-    #             self.logger.error("PutMessageTask for topicAndPartition: " +
-    #                               str(self.topicAndPartition) + " failed" + e.message)
-    #         finally:
-    #             # notify to wake up producer's global lock
-    #             with self.lock:
-    #                 self.globalLock.acquire()
-    #                 self.globalLock.notifyAll()
-    #                 self.globalLock.release()
-    #
-    #     self.process_buffered_message()
-
     def put_message(self, messageList=None, simpleProducer=None):
         userMessageResult = UserMessageResult(messageList,
                                               self.topicAndPartition.topicName,
@@ -238,8 +196,10 @@ class PartitionSender:
                                                                     self.userMessageCallback)
                 self.messageCallbackExecutors.start()
                 return True
-            except Exception as e:
-                self.logger.error("retry put message failed. " + e.message)
+            except Exception as ex:
+                if isinstance(ex, GalaxyTalosException):
+                    self.logger.error(ex.errMsg)
+                self.logger.error("retry put message failed. " + str(traceback.format_exc()))
 
             # 3. clear messageQueue when retry > 10 and partition buffer size > 10MB
             if retry >= self.talosProducerConfig.get_put_message_max_failed_times() and \
